@@ -37,8 +37,8 @@ function showPlaylistDialog() {
     }
 }
 
-function playVideo(video) {
-    YouTube.getVideoUrl(video.playerUrl);
+function playVideo(playerUrl) {
+    YouTube.getVideoUrl(playerUrl);
 }
 
 function addVideosToPlaybackQueue() {
